@@ -86,7 +86,7 @@
 #define KROSSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KROSSCORE_NO_DEPRECATED
-#  define KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KROSSCORE_NO_DEPRECATED_WARNINGS
 #  define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KROSSCORE_DEPRECATED_WARNINGS_SINCE KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KROSSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KROSSCORE_NO_DEPRECATED
-#  define KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KROSSCORE_NO_DEPRECATED_WARNINGS
 #  define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KROSSCORE_DEPRECATED_WARNINGS_SINCE KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
